@@ -4,6 +4,4 @@ from .exceptions import (  # noqa
     EventProcessorInvocationException,
     EventProcessorDecorationException,
 )
-from .pre_processors import passthrough  # noqa
-from .processor_decorator import processor, dependency_factory  # noqa
-from .processor_invoker import invoke  # noqa
+from .event_processor import EventProcessor  # noqa
